@@ -88,7 +88,7 @@ class Generation(models.Model):
         }
 
 class Country(models.Model):
-    code = models.CharField(max_length=1, unique=True)
+    code = models.CharField(max_length=3, unique=True)
     name = models.CharField(max_length=100, unique=True)
 
     def __unicode__(self):
@@ -103,10 +103,10 @@ class Type(models.Model):
     # for a few countries in the mapit/fixtures directory. In the UK we have
     # county councils (CTY), district councils (DIS), constituencies of the UK
     # Parliament (WMC), Scottish Parliament regions (SPE), and so on. The fact
-    # they are three letter codes is a hangover from the original source data
-    # we used from Ordnance Survey, and could potentially be changed.
+    # these examples are three letter codes is a hangover from the original
+    # source data we used from Ordnance Survey.
 
-    code = models.CharField(max_length=3, unique=True, help_text="A unique three letter code, eg 'CTR', 'CON', etc")
+    code = models.CharField(max_length=500, unique=True, help_text="A unique code, eg 'CTR', 'CON', etc")
     description = models.CharField(max_length=200, blank=True, help_text="The name of the type of area, eg 'Country', 'Constituency', etc")
 
     def __unicode__(self):
@@ -203,7 +203,7 @@ class TransformError(Exception):
     pass
 
 class Area(models.Model):
-    name = models.CharField(max_length=100, editable=False, blank=True) # Automatically set from name children
+    name = models.CharField(max_length=2000, editable=False, blank=True) # Automatically set from name children
     parent_area = models.ForeignKey('self', related_name='children', null=True, blank=True)
     type = models.ForeignKey(Type, related_name='areas')
     country = models.ForeignKey(Country, related_name='areas', null=True, blank=True)
@@ -315,20 +315,22 @@ class Area(models.Model):
             elif kml_type == "full":
                 out = '''<?xml version="1.0" encoding="UTF-8"?>
 <kml xmlns="http://www.opengis.net/kml/2.2">
-    <Style id="ourPolygonStyle">
-        <LineStyle>
-            <color>%s</color>
-            <width>2</width>
-        </LineStyle>
-        <PolyStyle>
-            <color>%s</color>
-        </PolyStyle>
-    </Style>
-    <Placemark>
-        <styleUrl>#ourPolygonStyle</styleUrl>
-        <name>%s</name>
-        %s
-    </Placemark>
+    <Document>
+        <Style id="ourPolygonStyle">
+            <LineStyle>
+                <color>%s</color>
+                <width>2</width>
+            </LineStyle>
+            <PolyStyle>
+                <color>%s</color>
+            </PolyStyle>
+        </Style>
+        <Placemark>
+            <styleUrl>#ourPolygonStyle</styleUrl>
+            <name>%s</name>
+            %s
+        </Placemark>
+    </Document>
 </kml>''' % (line_colour, fill_colour, escape(self.name), all_areas.kml)
             else:
                 raise Exception, "Unknown kml_type: '%s'" % (kml_type,)
